==> freetrain-exav-Beta2.0.2.11-r115.tar.gz: freetrain-exav-Beta2.0.2.11-r115/Beta2.0.2.11/trunk/plugins/org.kohsuke.freetrain.soccerStadium/src/StadiumPropertyDialog.cs <==
using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;

namespace freetrain.world.soccerstadium
{
	/// <summary>
	/// PropertyDialog for a stadium.
	/// </summary>
	internal class StadiumPropertyDialog : System.Windows.Forms.Form
	{
		private readonly StadiumStructure structure;

		#region Windows Form Designer generated code
		/// <summary>
		/// fUCi T|[gɕKvȃ\bhłB̃\bh̓e
		/// R[h GfB^ŕύXȂłB
		/// </summary>
		private void InitializeComponent()
		{
            this.label1 = new System.Windows.Forms.Label();
            this.stadiumName = new System.Windows.Forms.TextBox();
            this.label2 = new System.Windows.Forms.Label();
            this.teamName = new System.Windows.Forms.TextBox();
            this.okButton = new System.Windows.Forms.Button();
            this.cancelButton = new System.Windows.Forms.Button();
            this.label3 = new System.Windows.Forms.Label();
            this.pastGameView = new System.Windows.Forms.ListView();
            this.columnHeader4 = new System.Windows.Forms.ColumnHeader();
            this.columnHeader1 = new System.Windows.Forms.ColumnHeader();
            this.columnHeader2 = new System.Windows.Forms.ColumnHeader();
            this.columnHeader3 = new System.Windows.Forms.ColumnHeader();
            this.label4 = new System.Windows.Forms.Label();
            this.upcomingGameView = new System.Windows.Forms.ListView();
            this.columnHeader5 = new System.Windows.Forms.ColumnHeader();
            this.columnHeader6 = new System.Windows.Forms.ColumnHeader();
            this.groupBox1 = new System.Windows.Forms.GroupBox();
            this.button1 = new System.Windows.Forms.Button();
            this.advertise = new System.Windows.Forms.Button();
            this.labelwinlose = new System.Windows.Forms.Label();
            this.groupBox1.SuspendLayout();
            this.SuspendLayout();
            // 
            // label1
            // 
            this.label1.Location = new System.Drawing.Point(8, 8);
            this.label1.Name = "label1";
            this.label1.Size = new System.Drawing.Size(88, 16);
            this.label1.TabIndex = 0;
            this.label1.Text = "X^WA(&N):";
            this.label1.TextAlign = System.Drawing.ContentAlignment.BottomRight;
            // 
            // stadiumName
            // 
            this.stadiumName.Location = new System.Drawing.Point(104, 8);
            this.stadiumName.Name = "stadiumName";
            this.stadiumName.Size = new System.Drawing.Size(240, 19);
            this.stadiumName.TabIndex = 1;
            // 
            // label2
            // 
            this.label2.Location = new System.Drawing.Point(8, 32);
            this.label2.Name = "label2";
            this.label2.Size = new System.Drawing.Size(88, 16);
            this.label2.TabIndex = 2;
            this.label2.Text = "`[(&T):";
            this.label2.TextAlign = System.Drawing.ContentAlignment.BottomRight;
            // 
            // teamName
            // 
            this.teamName.Location = new System.Drawing.Point(104, 32);
            this.teamName.Name = "teamName";
            this.teamName.Size = new System.Drawing.Size(240, 19);
            this.teamName.TabIndex = 3;
            // 
            // okButton
            // 
            this.okButton.FlatStyle = System.Windows.Forms.FlatStyle.System;
            this.okButton.Location = new System.Drawing.Point(176, 416);
            this.okButton.Name = "okButton";
            this.okButton.Size = new System.Drawing.Size(80, 24);
            this.okButton.TabIndex = 4;
            this.okButton.Text = "&OK";
            this.okButton.Click += new System.EventHandler(this.onOK);
            // 
            // cancelButton
            // 
            this.cancelButton.DialogResult = System.Windows.Forms.DialogResult.Cancel;
            this.cancelButton.FlatStyle = System.Windows.Forms.FlatStyle.System;
            this.cancelButton.Location = new System.Drawing.Point(264, 416);
            this.cancelButton.Name = "cancelButton";
            this.cancelButton.Size = new System.Drawing.Size(80, 24);
            this.cancelButton.TabIndex = 5;
            this.cancelButton.Text = "ݾ(&C)";
            // 
            // label3
            // 
            this.label3.Location = new System.Drawing.Point(8, 104);
            this.label3.Name = "label3";
            this.label3.Size = new System.Drawing.Size(96, 16);
            this.label3.TabIndex = 6;
            this.label3.Text = "ŋ߂̑ΐ퐬:";
            // 
            // pastGameView
            // 
            this.pastGameView.Columns.AddRange(new System.Windows.Forms.ColumnHeader[] {
            this.columnHeader4,
            this.columnHeader1,
            this.columnHeader2,
            this.columnHeader3});
            this.pastGameView.FullRowSelect = true;
            this.pastGameView.HeaderStyle = System.Windows.Forms.ColumnHeaderStyle.Nonclickable;
            this.pastGameView.Location = new System.Drawing.Point(8, 120);
            this.pastGameView.Name = "pastGameView";
            this.pastGameView.Size = new System.Drawing.Size(336, 80);
            this.pastGameView.TabIndex = 7;
            this.pastGameView.UseCompatibleStateImageBehavior = false;
            this.pastGameView.View = System.Windows.Forms.View.Details;
            // 
            // columnHeader4
            // 
            this.columnHeader4.Text = "t";
            this.columnHeader4.Width = 57;
            // 
            // columnHeader1
            // 
            this.columnHeader1.Text = "ΐ푊";
            this.columnHeader1.Width = 100;
            // 
            // columnHeader2
            // 
            this.columnHeader2.Text = "XRA";
            this.columnHeader2.TextAlign = System.Windows.Forms.HorizontalAlignment.Center;
            // 
            // columnHeader3
            // 
            this.columnHeader3.Text = "ϋq";
            this.columnHeader3.TextAlign = System.Windows.Forms.HorizontalAlignment.Right;
            this.columnHeader3.Width = 80;
            // 
            // label4
            // 
            this.label4.Location = new System.Drawing.Point(8, 216);
            this.label4.Name = "label4";
            this.label4.Size = new System.Drawing.Size(96, 16);
            this.label4.TabIndex = 8;
            this.label4.Text = "̑ΐ\:";
            // 
            // upcomingGameView
            // 
            this.upcomingGameView.Columns.AddRange(new System.Windows.Forms.ColumnHeader[] {
            this.columnHeader5,
            this.columnHeader6});
            this.upcomingGameView.FullRowSelect = true;
            this.upcomingGameView.HeaderStyle = System.Windows.Forms.ColumnHeaderStyle.Nonclickable;
            this.upcomingGameView.Location = new System.Drawing.Point(8, 232);
            this.upcomingGameView.Name = "upcomingGameView";
            this.upcomingGameView.Size = new System.Drawing.Size(336, 80);
            this.upcomingGameView.TabIndex = 9;
            this.upcomingGameView.UseCompatibleStateImageBehavior = false;
            this.upcomingGameView.View = System.Windows.Forms.View.Details;
            // 
            // columnHeader5
            // 
            this.columnHeader5.Text = "t";
            // 
            // columnHeader6
            // 
            this.columnHeader6.Text = "ΐ푊";
            this.columnHeader6.Width = 131;
            // 
            // groupBox1
            // 
            this.groupBox1.Controls.Add(this.button1);
            this.groupBox1.Controls.Add(this.advertise);
            this.groupBox1.Location = new System.Drawing.Point(8, 320);
            this.groupBox1.Name = "groupBox1";
            this.groupBox1.Size = new System.Drawing.Size(336, 80);
            this.groupBox1.TabIndex = 10;
            this.groupBox1.TabStop = false;
            this.groupBox1.Text = "`[^c";
            // 
            // button1
            // 
            this.button1.FlatStyle = System.Windows.Forms.FlatStyle.System;
            this.button1.Location = new System.Drawing.Point(8, 48);
            this.button1.Name = "button1";
            this.button1.Size = new System.Drawing.Size(320, 24);
            this.button1.TabIndex = 1;
            this.button1.Text = "`[PR (100,000)";
            this.button1.Click += new System.EventHandler(this.doPR);
            // 
            // advertise
            // 
            this.advertise.FlatStyle = System.Windows.Forms.FlatStyle.System;
            this.advertise.Location = new System.Drawing.Point(8, 16);
            this.advertise.Name = "advertise";
            this.advertise.Size = new System.Drawing.Size(320, 24);
            this.advertise.TabIndex = 0;
            this.advertise.Text = "`[͕⋭ (100,000)";
            this.advertise.Click += new System.EventHandler(this.reinforce);
            // 
            // labelwinlose
            //
            int Maches = structure.maches;
            int Wins = structure.wins;
            int Draws = structure.draws;
            int Loses = Maches - Wins - Draws;
            this.labelwinlose.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
                        | System.Windows.Forms.AnchorStyles.Left)
                        | System.Windows.Forms.AnchorStyles.Right)));
            this.labelwinlose.Location = new System.Drawing.Point(8, 69);
            this.labelwinlose.Name = "labelwinlose";
            this.labelwinlose.Size = new System.Drawing.Size(336, 24);
            this.labelwinlose.TabIndex = 11;
          this.labelwinlose.Text = "V[Yΐ퐬с@ "+Wins.ToString()+" "+Loses.ToString()+"s "+Draws.ToString()+"";
            // 
            // StadiumPropertyDialog
            // 
            this.AcceptButton = this.okButton;
            this.AutoScaleBaseSize = new System.Drawing.Size(5, 12);
            this.CancelButton = this.cancelButton;
            this.ClientSize = new System.Drawing.Size(354, 452);
            this.Controls.Add(this.labelwinlose);
            this.Controls.Add(this.groupBox1);
            this.Controls.Add(this.upcomingGameView);
            this.Controls.Add(this.label4);
            this.Controls.Add(this.pastGameView);
            this.Controls.Add(this.label3);
            this.Controls.Add(this.cancelButton);
            this.Controls.Add(this.okButton);
            this.Controls.Add(this.teamName);
            this.Controls.Add(this.label2);
            this.Controls.Add(this.stadiumName);
            this.Controls.Add(this.label1);
            this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
            this.MaximizeBox = false;
            this.MinimizeBox = false;
            this.Name = "StadiumPropertyDialog";
            this.ShowInTaskbar = false;
            this.Text = "TbJ[X^WA";
            this.groupBox1.ResumeLayout(false);
            this.ResumeLayout(false);
            this.PerformLayout();

		}
		#endregion
		#region controls
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.TextBox stadiumName;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.TextBox teamName;
		private System.Windows.Forms.Button okButton;
		private System.Windows.Forms.Button cancelButton;
		private System.Windows.Forms.Label label3;
		private System.Windows.Forms.ColumnHeader columnHeader1;
		private System.Windows.Forms.ColumnHeader columnHeader2;
		private System.Windows.Forms.ColumnHeader columnHeader3;
		private System.Windows.Forms.ColumnHeader columnHeader4;
		private System.Windows.Forms.Label label4;
		private System.Windows.Forms.ColumnHeader columnHeader5;
		private System.Windows.Forms.ColumnHeader columnHeader6;
		private System.Windows.Forms.GroupBox groupBox1;
		private System.Windows.Forms.Button advertise;
		private System.Windows.Forms.Button button1;
		private System.Windows.Forms.ListView pastGameView;
		private System.Windows.Forms.ListView upcomingGameView;
        private Label labelwinlose;
		private System.ComponentModel.Container components = null;
		#endregion

		internal StadiumPropertyDialog( StadiumStructure _structure ) {
			this.structure = _structure;

			InitializeComponent();

			stadiumName.Text = structure.stadiumName;
			teamName.Text = structure.teamName;

			foreach( Game g in structure.pastGames ) {
				ListViewItem lvi = g.createListItem();
				pastGameView.Items.Add( lvi );
				lvi.EnsureVisible();
			}
			
			foreach( Game g in structure.futureGames )
				upcomingGameView.Items.Add( g.createListItem() );
		}

		protected override void Dispose( bool disposing ) {
			if( disposing && components!=null )
				components.Dispose();
			base.Dispose( disposing );
		}


		private void onOK(object sender, EventArgs e) {
			structure.stadiumName = stadiumName.Text;
			structure.teamName = teamName.Text;

			Close();
		}

		private void reinforce(object sender, EventArgs e) {
			structure.reinforce();
		}

		private void doPR(object sender, EventArgs e) {
			structure.doPR();
		}
	}
}

==> freetrain-exav-Beta2.2.0.1-r115.tar.gz: freetrain-exav-Beta2.2.0.1-r115/Beta2.2.0.1/trunk/plugins/org.kohsuke.freetrain.soccerStadium/src/StadiumPropertyDialog.cs <==
using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;

namespace freetrain.world.soccerstadium
{
	/// <summary>
	/// PropertyDialog for a stadium.
	/// </summary>
	internal class StadiumPropertyDialog : System.Windows.Forms.Form
	{
		private readonly StadiumStructure structure;

		#region Windows Form Designer generated code
		/// <summary>
		/// fUCi T|[gɕKvȃ\bhłB̃\bh̓e
		/// R[h GfB^ŕύXȂłB
		/// </summary>
		private void InitializeComponent()
		{
            this.label1 = new System.Windows.Forms.Label();
            this.stadiumName = new System.Windows.Forms.TextBox();
            this.label2 = new System.Windows.Forms.Label();
            this.teamName = new System.Windows.Forms.TextBox();
            this.okButton = new System.Windows.Forms.Button();
            this.cancelButton = new System.Windows.Forms.Button();
            this.label3 = new System.Windows.Forms.Label();
            this.pastGameView = new System.Windows.Forms.ListView();
            this.columnHeader4 = new System.Windows.Forms.ColumnHeader();
            this.columnHeader1 = new System.Windows.Forms.ColumnHeader();
            this.columnHeader2 = new System.Windows.Forms.ColumnHeader();
            this.columnHeader3 = new System.Windows.Forms.ColumnHeader();
            this.label4 = new System.Windows.Forms.Label();
            this.upcomingGameView = new System.Windows.Forms.ListView();
            this.columnHeader5 = new System.Windows.Forms.ColumnHeader();
            this.columnHeader6 = new System.Windows.Forms.ColumnHeader();
            this.groupBox1 = new System.Windows.Forms.GroupBox();
            this.button1 = new System.Windows.Forms.Button();
            this.advertise = new System.Windows.Forms.Button();
            this.labelwinlose = new System.Windows.Forms.Label();
            this.groupBox1.SuspendLayout();
            this.SuspendLayout();
            // 
            // label1
            // 
            this.label1.Location = new System.Drawing.Point(8, 8);
            this.label1.Name = "label1";
            this.label1.Size = new System.Drawing.Size(88, 16);
            this.label1.TabIndex = 0;
            this.label1.Text = "X^WA(&N):";
            this.label1.TextAlign = System.Drawing.ContentAlignment.BottomRight;
            // 
            // stadiumName
            // 
            this.stadiumName.Location = new System.Drawing.Point(104, 8);
            this.stadiumName.Name = "stadiumName";
            this.stadiumName.Size = new System.Drawing.Size(240, 19);
            this.stadiumName.TabIndex = 1;
            // 
            // label2
            // 
            this.label2.Location = new System.Drawing.Point(8, 32);
            this.label2.Name = "label2";
            this.label2.Size = new System.Drawing.Size(88, 16);
            this.label2.TabIndex = 2;
            this.label2.Text = "`[(&T):";
            this.label2.TextAlign = System.Drawing.ContentAlignment.BottomRight;
            // 
            // teamName
            // 
            this.teamName.Location = new System.Drawing.Point(104, 32);
            this.teamName.Name = "teamName";
            this.teamName.Size = new System.Drawing.Size(240, 19);
            this.teamName.TabIndex = 3;
            // 
            // okButton
            // 
            this.okButton.FlatStyle = System.Windows.Forms.FlatStyle.System;
            this.okButton.Location = new System.Drawing.Point(176, 416);
            this.okButton.Name = "okButton";
            this.okButton.Size = new System.Drawing.Size(80, 24);
            this.okButton.TabIndex = 4;
            this.okButton.Text = "&OK";
            this.okButton.Click += new System.EventHandler(this.onOK);
            // 
            // cancelButton
            // 
            this.cancelButton.DialogResult = System.Windows.Forms.DialogResult.Cancel;
            this.cancelButton.FlatStyle = System.Windows.Forms.FlatStyle.System;
            this.cancelButton.Location = new System.Drawing.Point(264, 416);
            this.cancelButton.Name = "cancelButton";
            this.cancelButton.Size = new System.Drawing.Size(80, 24);
            this.cancelButton.TabIndex = 5;
            this.cancelButton.Text = "ݾ(&C)";
            // 
            // label3
            // 
            this.label3.Location = new System.Drawing.Point(8, 104);
            this.label3.Name = "label3";
            this.label3.Size = new System.Drawing.Size(96, 16);
            this.label3.TabIndex = 6;
            this.label3.Text = "ŋ߂̑ΐ퐬:";
            // 
            // pastGameView
            // 
            this.pastGameView.Columns.AddRange(new System.Windows.Forms.ColumnHeader[] {
            this.columnHeader4,
            this.columnHeader1,
            this.columnHeader2,
            this.columnHeader3});
            this.pastGameView.FullRowSelect = true;
            this.pastGameView.HeaderStyle = System.Windows.Forms.ColumnHeaderStyle.Nonclickable;
            this.pastGameView.Location = new System.Drawing.Point(8, 120);
            this.pastGameView.Name = "pastGameView";
            this.pastGameView.Size = new System.Drawing.Size(336, 80);
            this.pastGameView.TabIndex = 7;
            this.pastGameView.UseCompatibleStateImageBehavior = false;
            this.pastGameView.View = System.Windows.Forms.View.Details;
            // 
            // columnHeader4
            // 
            this.columnHeader4.Text = "t";
            this.columnHeader4.Width = 57;
            // 
            // columnHeader1
            // 
            this.columnHeader1.Text = "ΐ푊";
            this.columnHeader1.Width = 100;
            // 
            // columnHeader2
            // 
            this.columnHeader2.Text = "XRA";
            this.columnHeader2.TextAlign = System.Windows.Forms.HorizontalAlignment.Center;
            // 
            // columnHeader3
            // 
            this.columnHeader3.Text = "ϋq";
            this.columnHeader3.TextAlign = System.Windows.Forms.HorizontalAlignment.Right;
            this.columnHeader3.Width = 80;
            // 
            // label4
            // 
            this.label4.Location = new System.Drawing.Point(8, 216);
            this.label4.Name = "label4";
            this.label4.Size = new System.Drawing.Size(96, 16);
            this.label4.TabIndex = 8;
            this.label4.Text = "̑ΐ\:";
            // 
            // upcomingGameView
            // 
            this.upcomingGameView.Columns.AddRange(new System.Windows.Forms.ColumnHeader[] {
            this.columnHeader5,
            this.columnHeader6});
            this.upcomingGameView.FullRowSelect = true;
            this.upcomingGameView.HeaderStyle = System.Windows.Forms.ColumnHeaderStyle.Nonclickable;
            this.upcomingGameView.Location = new System.Drawing.Point(8, 232);
            this.upcomingGameView.Name = "upcomingGameView";
            this.upcomingGameView.Size = new System.Drawing.Size(336, 80);
            this.upcomingGameView.TabIndex = 9;
            this.upcomingGameView.UseCompatibleStateImageBehavior = false;
            this.upcomingGameView.View = System.Windows.Forms.View.Details;
            // 
            // columnHeader5
            // 
            this.columnHeader5.Text = "t";
            // 
            // columnHeader6
            // 
            this.columnHeader6.Text = "ΐ푊";
            this.columnHeader6.Width = 131;
            // 
            // groupBox1
            // 
            this.groupBox1.Controls.Add(this.button1);
            this.groupBox1.Controls.Add(this.advertise);
            this.groupBox1.Location = new System.Drawing.Point(8, 320);
            this.groupBox1.Name = "groupBox1";
            this.groupBox1.Size = new System.Drawing.Size(336, 80);
            this.groupBox1.TabIndex = 10;
            this.groupBox1.TabStop = false;
            this.groupBox1.Text = "`[^c";
            // 
            // button1
            // 
            this.button1.FlatStyle = System.Windows.Forms.FlatStyle.System;
            this.button1.Location = new System.Drawing.Point(8, 48);
            this.button1.Name = "button1";
            this.button1.Size = new System.Drawing.Size(320, 24);
            this.button1.TabIndex = 1;
            this.button1.Text = "`[PR (10,000,000)";
            this.button1.Click += new System.EventHandler(this.doPR);
            // 
            // advertise
            // 
            this.advertise.FlatStyle = System.Windows.Forms.FlatStyle.System;
            this.advertise.Location = new System.Drawing.Point(8, 16);
            this.advertise.Name = "advertise";
            this.advertise.Size = new System.Drawing.Size(320, 24);
            this.advertise.TabIndex = 0;
            this.advertise.Text = "`[͕⋭ (10,000,000)";
            this.advertise.Click += new System.EventHandler(this.reinforce);
            // 
            // labelwinlose
            //
            int Maches = structure.maches;
            int Wins = structure.wins;
            int Draws = structure.draws;
            int Loses = Maches - Wins - Draws;
            this.labelwinlose.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
                        | System.Windows.Forms.AnchorStyles.Left)
                        | System.Windows.Forms.AnchorStyles.Right)));
            this.labelwinlose.Location = new System.Drawing.Point(8, 69);
            this.labelwinlose.Name = "labelwinlose";
            this.labelwinlose.Size = new System.Drawing.Size(336, 24);
            this.labelwinlose.TabIndex = 11;
          this.labelwinlose.Text = "V[Yΐ퐬с@ "+Wins.ToString()+" "+Loses.ToString()+"s "+Draws.ToString()+"";
            // 
            // StadiumPropertyDialog
            // 
            this.AcceptButton = this.okButton;
            this.AutoScaleBaseSize = new System.Drawing.Size(5, 12);
            this.CancelButton = this.cancelButton;
            this.ClientSize = new System.Drawing.Size(354, 452);
            this.Controls.Add(this.labelwinlose);
            this.Controls.Add(this.groupBox1);
            this.Controls.Add(this.upcomingGameView);
            this.Controls.Add(this.label4);
            this.Controls.Add(this.pastGameView);
            this.Controls.Add(this.label3);
            this.Controls.Add(this.cancelButton);
            this.Controls.Add(this.okButton);
            this.Controls.Add(this.teamName);
            this.Controls.Add(this.label2);
            this.Controls.Add(this.stadiumName);
            this.Controls.Add(this.label1);
            this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
            this.MaximizeBox = false;
            this.MinimizeBox = false;
            this.Name = "StadiumPropertyDialog";
            this.ShowInTaskbar = false;
            this.Text = "TbJ[X^WA";
            this.groupBox1.ResumeLayout(false);
            this.ResumeLayout(false);
            this.PerformLayout();

		}
		#endregion
		#region controls
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.TextBox stadiumName;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.TextBox teamName;
		private System.Windows.Forms.Button okButton;
		private System.Windows.Forms.Button cancelButton;
		private System.Windows.Forms.Label label3;
		private System.Windows.Forms.ColumnHeader columnHeader1;
		private System.Windows.Forms.ColumnHeader columnHeader2;
		private System.Windows.Forms.ColumnHeader columnHeader3;
		private System.Windows.Forms.ColumnHeader columnHeader4;
		private System.Windows.Forms.Label label4;
		private System.Windows.Forms.ColumnHeader columnHeader5;
		private System.Windows.Forms.ColumnHeader columnHeader6;
		private System.Windows.Forms.GroupBox groupBox1;
		private System.Windows.Forms.Button advertise;
		private System.Windows.Forms.Button button1;
		private System.Windows.Forms.ListView pastGameView;
		private System.Windows.Forms.ListView upcomingGameView;
        private Label labelwinlose;
		private System.ComponentModel.Container components = null;
		#endregion

		internal StadiumPropertyDialog( StadiumStructure _structure ) {
			this.structure = _structure;

			InitializeComponent();

			stadiumName.Text = structure.stadiumName;
			teamName.Text = structure.teamName;

			foreach( Game g in structure.pastGames ) {
				ListViewItem lvi = g.createListItem();
				pastGameView.Items.Add( lvi );
				lvi.EnsureVisible();
			}
			
			foreach( Game g in structure.futureGames )
				upcomingGameView.Items.Add( g.createListItem() );
		}

		protected override void Dispose( bool disposing ) {
			if( disposing && components!=null )
				components.Dispose();
			base.Dispose( disposing );
		}


		private void onOK(object sender, EventArgs e) {
			structure.stadiumName = stadiumName.Text;
			structure.teamName = teamName.Text;

			Close();
		}

		private void reinforce(object sender, EventArgs e) {
			structure.reinforce();
		}

		private void doPR(object sender, EventArgs e) {
			structure.doPR();
		}
	}
}
